pub enum Commands {
Apply {
input: PathBuf,
preset: Option<PathBuf>,
presets: Vec<PathBuf>,
output: PathBuf,
output_opts: OutputOpts,
},
Edit {
input: PathBuf,
output: PathBuf,
edit: EditArgs,
output_opts: OutputOpts,
},
BatchApply {
preset: PathBuf,
batch: BatchOpts,
},
BatchEdit {
edit: EditArgs,
batch: BatchOpts,
},
MultiApply {
input: PathBuf,
preset: Vec<PathBuf>,
output: PathBuf,
noop: bool,
jobs: usize,
},
Validate {
paths: Vec<PathBuf>,
quiet: bool,
format: OutputFormat,
},
}Expand description
Supported CLI subcommands.
Variants
Apply
Apply a TOML preset to an image
Fields

output_opts: OutputOptsShared output encoding options.
Edit
Edit an image with inline parameters
Fields

output_opts: OutputOptsShared output encoding options.
BatchApply
Apply a TOML preset to all images in a directory
BatchEdit
Edit all images in a directory with inline parameters
MultiApply
Apply multiple presets to a single image (decode once, render per preset)
Fields
Validate
Validate one or more preset files for correctness without rendering.
Reports unknown fields, type mismatches, out-of-range values, missing LUT files, and extends chain problems. Exits 0 if all clean, 1 if any file has errors.